"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const ml_core_1 = require("@markuplint/ml-core");
const i18n_1 = require("./i18n");
const module_auto_loader_1 = require("./module-auto-loader");
const path_1 = __importDefault(require("path"));
const util_1 = require("./util");
async function lintFile(file, configs, rulesAutoResolve, rules, locale, fix) {
    const configSet = configs.get(file) || {
        config: {},
        files: new Set(),
        errs: [],
    };
    // Get parser
    let parserModName = '@markuplint/html-parser';
    if (configSet.config.parser) {
        for (const pattern of Object.keys(configSet.config.parser)) {
            if (path_1.default.basename(file.path).match(util_1.toRegxp(pattern))) {
                parserModName = configSet.config.parser[pattern];
            }
        }
    }
    const parser = await Promise.resolve().then(() => __importStar(require(parserModName)));
    // Resolve ruleset
    const ruleset = ml_core_1.convertRuleset(configSet.config);
    // Addition rules
    if (rulesAutoResolve) {
        const { rules: additionalRules } = await module_auto_loader_1.moduleAutoLoader(ruleset);
        rules = rules.concat(...additionalRules);
    }
    // create MLCore
    const sourceCode = await file.getContext();
    const i18nSettings = await i18n_1.i18n(locale);
    const core = new ml_core_1.MLCore(parser, sourceCode, ruleset, rules, i18nSettings);
    const results = await core.verify(fix);
    return {
        results,
        filePath: file.path,
        sourceCode,
        fixedCode: core.document.toString(),
        document: core.document,
        parser: parserModName,
        locale,
        ruleset,
        configSet: {
            config: configSet.config,
            files: Array.from(configSet.files),
            error: configSet.errs.map(e => `${e}`),
        },
    };
}
exports.lintFile = lintFile;
